==> maplink-fabric-4.0.1-1.18.2-sources.jar: de/the_build_craft/maplink/common/clientMapHandlers/XaeroIconRenderData.java <==
/*
 *    This file is part of the Map Link mod
 *    licensed under the GNU GPL v3 License.
 *
 *    Copyright (C) 2025  Leander Knüttel and contributors
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package de.the_build_craft.maplink.common.clientMapHandlers;

#if MC_VER >= MC_1_19_4
import net.minecraft.class_1159;
import org.joml.Matrix4f;
#endif

/**
 * @author Leander Knüttel
 * @version 25.08.2025
 */
public class XaeroIconRenderData {
    public final class_1159 pose;
    public final float x;
    public final float y;
    public final int width;
    public final int height;
    public final float a;

    public XaeroIconRenderData(class_1159 pose, float x, float y, int width, int height, float a) {
        this.pose = pose;
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        this.a = a;
    }
}

==> maplink-fabric-4.0.2-1.21.9-1.21.10-sources.jar: de/the_build_craft/maplink/common/clientMapHandlers/XaeroIconRenderData.java <==
/*
 *    This file is part of the Map Link mod
 *    licensed under the GNU GPL v3 License.
 *
 *    Copyright (C) 2025  Leander Knüttel and contributors
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package de.the_build_craft.maplink.common.clientMapHandlers;

#if MC_VER >= MC_1_19_4
import org.joml.Matrix4f;
#else
import com.mojang.math.Matrix4f;
#endif

/**
 * @author Leander Knüttel
 * @version 25.08.2025
 */
public class XaeroIconRenderData {
    public final org.joml.Matrix4f pose;
    public final float x;
    public final float y;
    public final int width;
    public final int height;
    public final float a;

    public XaeroIconRenderData(org.joml.Matrix4f pose, float x, float y, int width, int height, float a) {
        this.pose = pose;
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        this.a = a;
    }
}
